This python module allows you to contact your Guntamatic BMK heater and get operational status informatio
It includes an example binary 'heater.py' which can be installed as the guntamatic binary to instantly get data in your cli.
The Guntamatic class can be used by IOT frameworks to be called regularly and plot data and the like.

The exact outputs might depend on your model and firmware.


